using System;
using System.Data;
using System.Data.Common;
using System.Data.OleDb;


namespace ShopClassLibrary
{
	/// <summary>
	/// Summary description for interface ICustomer.
	/// </summary>
	public interface ICustomer
	{
		DataSet GetByID(string user, string pass, long clientID);

		DataSet FindByName(string user, string pass, string namePattern);

		long Add(string user, string pass, 
			     string name, string address, string phone, 
				 string fax, string eMail, out ShopStatusEnum status);

		ShopStatusEnum Update(string user, string pass, 
			                  long custumerID, string name, string address, 
							  string phone, string fax, string eMail);
	}

	/// <summary>
	/// Summary description for Customer.
	/// </summary>
	public class Customer : ICustomer
	{
		public Customer()
		{
			//
			// TODO: Add constructor logic here
			//
		}

		public DataSet GetByID(string user, string pass, long clientID)
		{
			ShopStatusEnum status = Comum.ValidateUser(user, pass);

			if (status != ShopStatusEnum.OK)
			{
				return null;
			}

			DataSet ds = Comum.GetByID("Customers", "CustomerID", clientID);

			return ds;
		}

		public DataSet FindByName(string user, string pass, string namePattern)
		{
			ShopStatusEnum status = Comum.ValidateUser(user, pass);

			if (status != ShopStatusEnum.OK)
			{
				return null;
			}
			
			//
			// codigo a alterar
			// Dataset ds = Comum.FindByStringField("Customers", "Name", sNamePattern);
			//
			// return ds;
			//

			return null;
		}

		public long Add(string user, string pass, 
			            string name, string address, string phone, string fax, 
			            string eMail, out ShopStatusEnum status)
		{
			//
			// validar o utilizador
			//
			ShopStatusEnum l_stat = Comum.ValidateUser(user, pass);
			if (l_stat != ShopStatusEnum.OK)
			{
				status = l_stat;
				return -1;
			}

			long lCustomerID = -1;
			OleDbConnection conn = null;

			try
			{	
				//
				// criar objecto de conexo  base de dados e abrir a conexo
				//
				conn = new OleDbConnection(Comum.CONN);
				conn.Open();

				//
				// criar comando SQL a executar
				//
				string sqlCmd = "INSERT INTO Customers (Name, Address, PhoneNb, FaxNb, EMail) " +
					"Values    ('" + name + "', '" + address + "', '" + phone + "', '" + fax + "', '" + eMail +"')";
				OleDbCommand cmd = new OleDbCommand(sqlCmd, conn);
		
				//
				// executar o comando 
				//
				int insRows = cmd.ExecuteNonQuery();

				//
				// verificar o resultado
				//
				if (insRows == 0)
					// no inseriu registo
					status = ShopStatusEnum.NOT_OK;
				else
				{
					//
					// inseriu registo
					// obter novo cdigo de id gerado pela BD
					//
					OleDbCommand idCmd = new OleDbCommand("SELECT @@IDENTITY", conn);
					lCustomerID = (int)idCmd.ExecuteScalar();
					status = ShopStatusEnum.OK;		
				}
			}

			catch(OleDbException ex)
			{
				//
				// tratar a excepo!!!!
				//
				System.Console.WriteLine("EXCEPO no mtodo <AddCustomer> 'class Customer': " + ex);
				status = ShopStatusEnum.ERROR;
			}

			finally
			{
				//
				// fechar a conexo
				//
				if (conn.State == ConnectionState.Open)
					conn.Close();
			}

			return lCustomerID;
		}

		public ShopStatusEnum Update(string user, string pass, 
			                         long customerID, string name, string address, 
									 string phone, string fax, string eMail)
		{
			//
			// validar o utilizador
			//
			ShopStatusEnum status = Comum.ValidateUser(user, pass);
			if (status != ShopStatusEnum.OK)
			{
				return status;
			}

			OleDbConnection conn = null;

			try
			{
				//
				// criar objecto de conexo  base de dados e abrir a conexo
				//
				conn = new OleDbConnection(Comum.CONN);
				conn.Open();
				
				//
				// criar comando SQL a executar
				//
				string sSqlCmd = "Update Customers SET Name = '"   + name +
					                              "', Address = '" + address +
					                              "', PhoneNb = '" + phone +
					                              "', FaxNb = '"   + fax +
					                              "', EMail = '"   + eMail +
					            "' WHERE CustomerID = " + customerID.ToString(); 
				OleDbCommand cmd = new OleDbCommand(sSqlCmd, conn);

				//
				// executar o comando 
				//
				int updRows = cmd.ExecuteNonQuery();

				//
				// verificar o resultado
				//
				if (updRows == 0)
					// no actualizou registo
					status = ShopStatusEnum.NOT_OK;
				else
					// actualizou registo
					status = ShopStatusEnum.OK;
			}

			catch(OleDbException ex)
			{
				//
				// tratar a excepo!!!!
				//
				System.Console.WriteLine("EXCEPO no mtodo <UpdateCustumerData> 'class Customer': " + ex);
				status = ShopStatusEnum.ERROR;
			}

			finally
			{
				//
				// fechar a conexo
				//
				if (conn.State == ConnectionState.Open)
					conn.Close();
			}


			return status;
		}
	}
}
